# Workspace Setup for Self-Built Software Discovery
### On this page
  * [Introduction](https://help.sap.com/docs/leanix/ea/workspace-setup-for-self-built-software-discovery#introduction)
  * [Provisioning and Configuration](https://help.sap.com/docs/leanix/ea/workspace-setup-for-self-built-software-discovery#provisioning-and-configuration)
  * [Customizing Relations](https://help.sap.com/docs/leanix/ea/workspace-setup-for-self-built-software-discovery#customizing-relations)
  * [Enabling Tech Stack Discovery](https://help.sap.com/docs/leanix/ea/workspace-setup-for-self-built-software-discovery#enabling-tech-stack-discovery)
  * [Meta Model Extension](https://help.sap.com/docs/leanix/ea/workspace-setup-for-self-built-software-discovery#meta-model-extension)


Provision the self-built software discovery feature in SAP LeanIX to enable microservice discovery. This extends the meta model with microservice fact sheets, custom relations, and additional context fields.
